@@ -62,12 +62,12 @@ static void ethernet_newlink(unsigned short type, int index,
 		if (ethernet->index != index)
 			continue;
 
-		if ((ethernet->flags & IFF_RUNNING) == (flags & IFF_RUNNING))
+		if ((ethernet->flags & IFF_LOWER_UP) == (flags & IFF_LOWER_UP))
 			continue;
 
 		ethernet->flags = flags;
 
-		if (ethernet->flags & IFF_RUNNING) {
+		if (ethernet->flags & IFF_LOWER_UP) {
 			DBG("carrier on");
 
 			netdev = connman_element_create(NULL);
@@ -76,7 +76,8 @@ static void ethernet_newlink(unsigned short type, int index,
 				netdev->subtype = CONNMAN_ELEMENT_SUBTYPE_NETWORK;
 				netdev->index   = element->index;
 
-				connman_element_register(netdev, element);
+				if (connman_element_register(netdev, element) < 0)
+					connman_element_unref(netdev);
 			}
 		} else {
 			DBG("carrier off");
